/******************************************************************************
 * Move_Command - A client moves his checkers.
 * $Id: Move_Command.java,v 1.12 2011/06/11 04:59:04 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: Move_Command.java,v $
 * Revision 1.12  2011/06/11 04:59:04  dick
 * [sg]et[po]Die[12] becomes [sg]et[XO]Die[12].
 *
 * Revision 1.11  2011/06/09 18:12:40  dick
 * Javadoc.
 *
 * Revision 1.10  2011/06/07 20:18:38  dick
 * Use Player, not JibsWriter for output.
 * Don't create unneccessary boards for no real reason.
 * Use player.startOfYourTurn() to decide double or roll.
 *
 * Revision 1.9  2011/06/06 03:18:26  dick
 * JibsMessages belongs in n.s.jibs.server, not n.s.jibs.gui
 *
 * Revision 1.8  2011/06/06 02:53:51  dick
 * Reverse the state of the "ok to double" check.
 *
 * Revision 1.7  2011/06/05 06:02:37  dick
 * Output the move string before the board that the move created.
 *
 * Revision 1.6  2011/06/05 02:30:01  dick
 * retab.
 *
 * Revision 1.5  2011/06/03 19:27:28  dick
 * game.winGame[XO]() just needs the points, not the other parameters.
 *
 * Revision 1.4  2011/06/03 00:25:09  dick
 * Player.show2Watcher() becomes show2Watchers().
 *
 * Revision 1.3  2011/06/02 19:31:46  dick
 * show2WatcherMove() is now just show2Watcher().
 *
 * Revision 1.2  2011/05/31 13:02:43  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.command;

import net.sourceforge.jibs.backgammon.BackgammonBoard;
import net.sourceforge.jibs.backgammon.JibsGame;
import net.sourceforge.jibs.backgammon.MoveBackgammon;
import net.sourceforge.jibs.server.JibsMessages;
import net.sourceforge.jibs.server.JibsServer;
import net.sourceforge.jibs.server.Player;

/** A client moves his checkers.  
 * This could trigger end of game handling.
 *
 * @author Axel Leucht
 * @author Dick Balaska
 * @version $Revision: 1.12 $ <br> $Date: 2011/06/11 04:59:04 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/command/Move_Command.java">cvs Move_Command.java</a>
 */
public class Move_Command implements JibsCommand {

	@Override
	public boolean execute(JibsServer jibsServer, Player player,
			String strArgs, String[] args) {
		JibsMessages jibsMessages = jibsServer.getJibsMessages();
		String msg = null;
		JibsGame game = player.getGame();

		if (game != null) {
			BackgammonBoard board = game.getBackgammonBoard();
			Player playerX = board.getPlayerX();
			Player playerO = board.getPlayerO();
			Player opponent = board.getOpponent(player);
			BackgammonBoard opBoard;
			MoveBackgammon move;
			BackgammonBoard movedBoard = null;
			int turn = board.getTurn();
			strArgs = strArgs.trim();

			switch (turn) {
			case 1: // O
				move = new MoveBackgammon(board);

				if (move.checkMove(playerO, strArgs, board.getCanMove())) {
					// m_both_move=%0 moves %1.
					Object[] obj = new Object[] { playerO.getName(), strArgs };
					msg = jibsMessages.convert("m_both_move", obj);
					playerX.println(msg);
					playerX.show2Watchers(msg);
					playerO.show2Watchers(msg);

					movedBoard = move.placeMoveO(strArgs);
					game.setBackgammonBoard(movedBoard);
					movedBoard.outBoard(playerX, "You", -turn, 0, 0, 0, 0);
					playerX.show2WatcherBoard(movedBoard, playerX.getName(), 0, 0,
							0, 0);		

					opBoard = movedBoard.switch2O();
					opBoard.outBoard(playerO, "You", -turn, 0, 0, 0, 0);
					playerO.show2WatcherBoard(opBoard, playerO.getName(), 0,
							0, 0, 0);
				}
				break;

			case -1: // X
				move = new MoveBackgammon(board);

				if (move.checkMove(playerX, strArgs, board.getCanMove())) {
					// m_both_move=%0 moves %1.
					Object[] obj = new Object[] { playerX.getName(), strArgs };
					msg = jibsMessages.convert("m_both_move", obj);
					playerO.println(msg);
					playerX.show2Watchers(msg);
					playerO.show2Watchers(msg);
					movedBoard = move.placeMoveX(strArgs);
					game.setBackgammonBoard(movedBoard);
					movedBoard.outBoard(playerX, "You", -turn, 0, 0, 0, 0);
					playerX.show2WatcherBoard(movedBoard, playerX.getName(), 0,
							0, 0, 0);

					opBoard = movedBoard.switch2O();
					opBoard.outBoard(playerO, "You", -turn, 0, 0, 0, 0);
					playerO.show2WatcherBoard(opBoard, playerX.getName(), 0, 0,
							0, 0);
				}
				break;
			}

			board = game.getBackgammonBoard();

			// won?
			if (board.getOnHomeX() >= 15) {
				// PlayerX has won !
				game.winGameX(-1);

				return true;
			}

			if (board.getOnHomeO() >= 15) {
				// PlayerO has won !
				game.winGameO(-1);

				return true;
			}

			switch (board.getTurn()) {
			case 1: // O
				board.getODie1().setValue(0);
				board.getODie2().setValue(0);

				break;

			case -1: // X
				board.getXDie1().setValue(0);
				board.getXDie2().setValue(0);

				break;
			}

			board.setTurn(-board.getTurn());
			opponent.startOfYourTurn(board);

		}

		return true;
	}
}
