/******************************************************************************
 * Tell_Command - Tell A player this message.
 * $Id: Tell_Command.java,v 1.5 2011/06/09 18:19:18 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: Tell_Command.java,v $
 * Revision 1.5  2011/06/09 18:19:18  dick
 * Use Player.println() instead of the JibsWriter.
 *
 * Revision 1.4  2011/06/06 03:18:26  dick
 * JibsMessages belongs in n.s.jibs.server, not n.s.jibs.gui
 *
 * Revision 1.3  2011/06/06 02:55:47  dick
 * getPlayer() comes from JibsServer now.
 *
 * Revision 1.2  2011/05/31 13:02:43  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.command;

import net.sourceforge.jibs.server.JibsMessages;
import net.sourceforge.jibs.server.JibsServer;
import net.sourceforge.jibs.server.Player;
import net.sourceforge.jibs.util.ClipConstants;

/** Tell a player this message
 *
 * @author Axel Leucht
 * @author Dick Balaska
 * @version $Revision: 1.5 $ <br> $Date: 2011/06/09 18:19:18 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/command/Tell_Command.java">cvs Tell_Command.java</a>
 */
public class Tell_Command implements JibsCommand {

	@Override
	public boolean execute(JibsServer jibsServer, Player player,
			String strArgs, String[] args) {
		JibsMessages messages = jibsServer.getJibsMessages();
		String msg;

		if (args.length >= 1) {
			Player destPlayer = jibsServer.getPlayer(args[1]);

			/*
			 * m_no_listen** %0 won't listen to you. m_you_gagged=** You can't
			 * talk if you won't listen. m_tell_yourself=You say to yourself: %0
			 */
			if (destPlayer != null) {
				int index = strArgs.indexOf(args[1]);
				String sayText = null;

				if (index >= 0) {
					sayText = strArgs.substring(index + args[1].length());
				}

				destPlayer.println(ClipConstants.CLIP_SAYS + " " +
						player.getName() + " " + sayText.trim());
				player.println(ClipConstants.CLIP_YOU_SAY + " " +
						destPlayer.getName() + " " + sayText.trim());
			} else {
				// m_noone=** There is no one called %0.
				Object[] obj = new Object[] { args[1] };

				msg = messages.convert("m_noone", obj);
				player.println(msg);
			}
		}

		return true;
	}
}
