/******************************************************************************
 * DateCellRenderer - Display a date in a table cell
 * $Id: DateCellRenderer.java,v 1.2 2011/05/31 14:50:48 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: DateCellRenderer.java,v $
 * Revision 1.2  2011/05/31 14:50:48  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.gui;

import java.awt.Component;

import java.text.SimpleDateFormat;

import java.util.Date;

import javax.swing.JTable;
import javax.swing.table.DefaultTableCellRenderer;

/** Display a date in a table cell
 *
 * @author Axel Leucht
 * @author Dick Balaska
 * @version $Revision: 1.2 $ <br> $Date: 2011/05/31 14:50:48 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/gui/DateCellRenderer.java">cvs DateCellRenderer.java</a>
 */
public class DateCellRenderer extends DefaultTableCellRenderer {
	private static final long serialVersionUID = -2689422704018338553L;

	public Component getTableCellRendererComponent(JTable table, Object value,
			boolean isSelected,
			boolean hasFocus, int row,
			int column) {
		super.getTableCellRendererComponent(table, value, isSelected, hasFocus,
				row, column);

		if (value instanceof Date) {
			// Use SimpleDateFormat class to get a formatted String from Date
			// object.
			String strDate = new SimpleDateFormat("MM-dd-yyyy        HH:mm:ss").format((Date) value);

			// Sorting algorithm will work with model value. So you dont need to
			// worry
			// about the renderer's display value.
			this.setText(strDate);
		}

		return this;
	}
}
