/******************************************************************************
 * JibsToggle.java - A map of player config settings that can be toggled.
 * $Id: JibsToggle.java,v 1.3 2011/06/05 06:03:55 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: JibsToggle.java,v $
 * Revision 1.3  2011/06/05 06:03:55  dick
 * whitespace.
 *
 * Revision 1.2  2011/05/31 15:25:49  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.util;

import org.apache.log4j.Logger;

import java.util.HashMap;
import java.util.Map;

/** A map of player config settings that can be toggled. 
 * 
 * @author Dick Balaska
 * @author Axel Leucht
 * @since 2005/03/30
 * @version $Revision: 1.3 $ <br> $Date: 2011/06/05 06:03:55 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/util/JibsToggle.java">cvs JibsToggle.java</a>
 */
public class JibsToggle {
	private static Logger logger = Logger.getLogger(JibsToggle.class);
	private Map<String, Boolean> toggleMap;

	public JibsToggle(String toggles) {
		toggleMap = new HashMap<String, Boolean>();

		String[] maps = {
				"allowpip", "autoboard", "autodouble", "automove",
				"away", "bell", "crawford", "double",
				"greedy", "moreboards", "moves", "notify",
				"ratings", "ready",	"report", "silent",
				"telnet", "watch", "wrap"
		};

		for (int i = 0; i < toggles.length(); i++) {
			char value = toggles.charAt(i);

			if (value == '0') {
				toggleMap.put(maps[i], Boolean.FALSE);
			} else {
				toggleMap.put(maps[i], Boolean.TRUE);
			}
		}
	}

	public Boolean get(String key) {
		Object obj = toggleMap.get(key);

		if (obj != null) {
			if (obj instanceof Boolean) {
				return (Boolean) obj;
			}

			return Boolean.FALSE;
		}

		logger.warn("JibsToggle:get(" + key + ") not defined.");

		return Boolean.FALSE;
	}

	public void set(String key, Boolean value) {
		toggleMap.put(key, value);
	}

	public Map<String, Boolean> getToggleMap() {
		return toggleMap;
	}

	public String toString() {
		String[] maps = {
				"allowpip", "autoboard", "autodouble", "automove",
				"away", "bell", "crawford", "double",
				"greedy", "moreboards", "moves", "notify",
				"ratings", "ready",	"report", "silent",
				"telnet", "watch", "wrap"
		};
		StringBuffer buffer = new StringBuffer();

		for (int i = 0; i < maps.length; i++) {
			Boolean bValue = toggleMap.get(maps[i]);

			if (bValue) {
				buffer.append("1");
			} else {
				buffer.append("0");
			}
		}

		return buffer.toString();
	}
}
